summaryrefslogtreecommitdiffstats
path: root/Bugzilla/Token.pm
diff options
context:
space:
mode:
Diffstat (limited to 'Bugzilla/Token.pm')
-rw-r--r--Bugzilla/Token.pm6
1 files changed, 3 insertions, 3 deletions
diff --git a/Bugzilla/Token.pm b/Bugzilla/Token.pm
index 0c2d42fe7..7db6b9165 100644
--- a/Bugzilla/Token.pm
+++ b/Bugzilla/Token.pm
@@ -216,7 +216,7 @@ sub Cancel {
my $template = Bugzilla->template;
$vars ||= {};
# Get information about the token being cancelled.
trick_taint($token);
my ($issuedate, $tokentype, $eventdata, $loginname) =
$dbh->selectrow_array('SELECT ' . $dbh->sql_date_format('issuedate') . ',
@@ -489,8 +489,8 @@ Bugzilla::Token - Provides different routines to manage tokens.
to the user to inform him about this action.
Params: $user_id: The user ID of the user account whose password tokens
- are cancelled.
- $reason: The reason why these tokens are cancelled.
+ are canceled.
+ $reason: The reason why these tokens are canceled.
Returns: Nothing.
@@ -216,7 +216,7 @@ sub Cancel {
my $template = Bugzilla->template;
$vars ||= {};
- # Get information about the token being cancelled.
+ # Get information about the token being canceled.
trick_taint($token);
my ($issuedate, $tokentype, $eventdata, $loginname) =